#ifndef __WMKEYS_H
#define __WMKEYS_H
#endif

/*
wmkeys.h
MKey constant definitions for all possible keys that the WINMACRO.DLL macro
engine recognizes.

Written by Ken Henderson.

Copyright (c) 1994 Ken Henderson

Last modification: 11-27-94

*/

  /*Possible combinations of shift keys -- note that some combinations overlap,
  i.e., Shift-Alt and Alt-Shift are identical, so there are fewer than you might
  think.  This enumerated type is used to build a comprehensive list of available
  keys in both the component and in its property editor.
  */

  #define PSNone 0
  #define PSControl 1
  #define PSAlternate 2
  #define PSEitherShift 3
  #define PSCtrlShift 4
  #define PSCtrlAlt 5
  #define PSShiftAlt 6
  #define PSCtrlShiftAlt 7

  /*This array is defined using the PossibleShifts enum from above.  It consists
  of bit flags OR'ed together to create shift status bytes corresponding to the
  possible shift states established by the enum.  This array is later used to
  set the high order byte of a temporary MKey from within a loop in order to
  build a list of all possible keys.
  */

  BYTE PossibleShiftStates[PSCtrlShiftAlt+1] =
  {0, CtrlOn, AltOn, ShiftOn, CtrlOn | ShiftOn, CtrlOn | AltOn, ShiftOn | AltOn,
   CtrlOn | AltOn | ShiftOn};

	/*This set lists all possible unshifted keys.  This list only lists
	primary keys, so shift or toggle keys would be inappropriate here.
	*/

  #define VK_SEMICOLON 186
  #define VK_EQUAL 187
  #define VK_COMMA 188
  #define VK_MINUS 189
  #define VK_PERIOD 190
  #define VK_SLASH 191
  #define VK_BACKQUOTE 192
  #define VK_LEFTBRACKET 219
  #define VK_BACKSLASH 220
  #define VK_RIGHTBRACKET 221
  #define VK_QUOTE 222
  #define VK_LAST VK_QUOTE

  #define VKEYMAX 59

  BYTE VKeys[VKEYMAX] =
  {
  VK_LBUTTON  ,
  VK_RBUTTON  ,
  VK_CANCEL   ,
  VK_MBUTTON  ,
  VK_BACK     ,
  VK_TAB      ,
  VK_CLEAR    ,
  VK_RETURN   ,
  VK_PAUSE    ,
  VK_ESCAPE   ,
  VK_SPACE    ,
  VK_PRIOR    ,       /*PGUP*/
  VK_NEXT     ,       /*PGDN*/
  VK_END      ,
  VK_HOME     ,
  VK_LEFT     ,
  VK_UP       ,
  VK_RIGHT    ,
  VK_DOWN     ,
  VK_INSERT   ,
  VK_DELETE   ,
  VK_NUMPAD0  ,
  VK_NUMPAD1  ,
  VK_NUMPAD2  ,
  VK_NUMPAD3  ,
  VK_NUMPAD4  ,
  VK_NUMPAD5  ,
  VK_NUMPAD6  ,
  VK_NUMPAD7  ,
  VK_NUMPAD8  ,
  VK_NUMPAD9  ,
  VK_MULTIPLY ,
  VK_ADD      ,
  VK_SUBTRACT ,
  VK_DECIMAL  ,
  VK_DIVIDE   ,
  VK_F1       ,
  VK_F2       ,
  VK_F3       ,
  VK_F4       ,
  VK_F5       ,
  VK_F6       ,
  VK_F7       ,
  VK_F8       ,
  VK_F9       ,
  VK_F10      ,
  VK_F11      ,
  VK_F12      ,
  VK_SEMICOLON,
  VK_EQUAL,
  VK_COMMA,
  VK_MINUS,
  VK_PERIOD,
  VK_SLASH,
  VK_BACKQUOTE,
  VK_LEFTBRACKET,
  VK_BACKSLASH,
  VK_RIGHTBRACKET,
  VK_QUOTE
  };

BYTE ExtendedVKeys[10] =
  {VK_UP,
   VK_DOWN,
   VK_LEFT,
   VK_RIGHT,
   VK_HOME,
   VK_END,
	VK_PRIOR,  /*PGUP*/
   VK_NEXT,   /*PGDN*/
   VK_INSERT,
   VK_DELETE};


  #define MK_LBTN 1
  #define MK_CTRLLBTN 257
  #define MK_ALTLBTN 513
  #define MK_SHIFTLBTN 1025
  #define MK_CTRLSHIFTLBTN 1281
  #define MK_CTRLALTLBTN 769
  #define MK_ALTSHIFTLBTN 1537
  #define MK_CTRLALTSHIFTLBTN 1793
  #define MK_RBTN 2
  #define MK_CTRLRBTN 258
  #define MK_ALTRBTN 514
  #define MK_SHIFTRBTN 1026
  #define MK_CTRLSHIFTRBTN 1282
  #define MK_CTRLALTRBTN 770
  #define MK_ALTSHIFTRBTN 1538
  #define MK_CTRLALTSHIFTRBTN 1794
  #define MK_CANCEL 3
  #define MK_CTRLCANCEL 259
  #define MK_ALTCANCEL 515
  #define MK_SHIFTCANCEL 1027
  #define MK_CTRLSHIFTCANCEL 1283
  #define MK_CTRLALTCANCEL 771
  #define MK_ALTSHIFTCANCEL 1539
  #define MK_CTRLALTSHIFTCANCEL 1795
  #define MK_MBTN 4
  #define MK_CTRLMBTN 260
  #define MK_ALTMBTN 516
  #define MK_SHIFTMBTN 1028
  #define MK_CTRLSHIFTMBTN 1284
  #define MK_CTRLALTMBTN 772
  #define MK_ALTSHIFTMBTN 1540
  #define MK_CTRLALTSHIFTMBTN 1796
  #define MK_BACKSPACE 8
  #define MK_CTRLBACKSPACE 264
  #define MK_ALTBACKSPACE 520
  #define MK_SHIFTBACKSPACE 1032
  #define MK_CTRLSHIFTBACKSPACE 1288
  #define MK_CTRLALTBACKSPACE 776
  #define MK_ALTSHIFTBACKSPACE 1544
  #define MK_CTRLALTSHIFTBACKSPACE 1800
  #define MK_TAB 9
  #define MK_CTRLTAB 265
  #define MK_ALTTAB 521
  #define MK_SHIFTTAB 1033
  #define MK_CTRLSHIFTTAB 1289
  #define MK_CTRLALTTAB 777
  #define MK_ALTSHIFTTAB 1545
  #define MK_CTRLALTSHIFTTAB 1801
  #define MK_CENTER 12
  #define MK_CTRLCENTER 268
  #define MK_ALTCENTER 524
  #define MK_SHIFTCENTER 1036
  #define MK_CTRLSHIFTCENTER 1292
  #define MK_CTRLALTCENTER 780
  #define MK_ALTSHIFTCENTER 1548
  #define MK_CTRLALTSHIFTCENTER 1804
  #define MK_ENTER 13
  #define MK_CTRLENTER 269
  #define MK_ALTENTER 525
  #define MK_SHIFTENTER 1037
  #define MK_CTRLSHIFTENTER 1293
  #define MK_CTRLALTENTER 781
  #define MK_ALTSHIFTENTER 1549
  #define MK_CTRLALTSHIFTENTER 1805
  #define MK_PAUSE 19
  #define MK_CTRLPAUSE 275
  #define MK_ALTPAUSE 531
  #define MK_SHIFTPAUSE 1043
  #define MK_CTRLSHIFTPAUSE 1299
  #define MK_CTRLALTPAUSE 787
  #define MK_ALTSHIFTPAUSE 1555
  #define MK_CTRLALTSHIFTPAUSE 1811
  #define MK_ESC 27
  #define MK_CTRLESC 283
  #define MK_ALTESC 539
  #define MK_SHIFTESC 1051
  #define MK_CTRLSHIFTESC 1307
  #define MK_CTRLALTESC 795
  #define MK_ALTSHIFTESC 1563
  #define MK_CTRLALTSHIFTESC 1819
  #define MK_SPACE 32
  #define MK_CTRLSPACE 288
  #define MK_ALTSPACE 544
  #define MK_SHIFTSPACE 1056
  #define MK_CTRLSHIFTSPACE 1312
  #define MK_CTRLALTSPACE 800
  #define MK_ALTSHIFTSPACE 1568
  #define MK_CTRLALTSHIFTSPACE 1824
  #define MK_PGUP 33
  #define MK_CTRLPGUP 289
  #define MK_ALTPGUP 545
  #define MK_SHIFTPGUP 1057
  #define MK_CTRLSHIFTPGUP 1313
  #define MK_CTRLALTPGUP 801
  #define MK_ALTSHIFTPGUP 1569
  #define MK_CTRLALTSHIFTPGUP 1825
  #define MK_PGDN 34
  #define MK_CTRLPGDN 290
  #define MK_ALTPGDN 546
  #define MK_SHIFTPGDN 1058
  #define MK_CTRLSHIFTPGDN 1314
  #define MK_CTRLALTPGDN 802
  #define MK_ALTSHIFTPGDN 1570
  #define MK_CTRLALTSHIFTPGDN 1826
  #define MK_END 35
  #define MK_CTRLEND 291
  #define MK_ALTEND 547
  #define MK_SHIFTEND 1059
  #define MK_CTRLSHIFTEND 1315
  #define MK_CTRLALTEND 803
  #define MK_ALTSHIFTEND 1571
  #define MK_CTRLALTSHIFTEND 1827
  #define MK_HOME 36
  #define MK_CTRLHOME 292
  #define MK_ALTHOME 548
  #define MK_SHIFTHOME 1060
  #define MK_CTRLSHIFTHOME 1316
  #define MK_CTRLALTHOME 804
  #define MK_ALTSHIFTHOME 1572
  #define MK_CTRLALTSHIFTHOME 1828
  #define MK_LEFT 37
  #define MK_CTRLLEFT 293
  #define MK_ALTLEFT 549
  #define MK_SHIFTLEFT 1061
  #define MK_CTRLSHIFTLEFT 1317
  #define MK_CTRLALTLEFT 805
  #define MK_ALTSHIFTLEFT 1573
  #define MK_CTRLALTSHIFTLEFT 1829
  #define MK_UP 38
  #define MK_CTRLUP 294
  #define MK_ALTUP 550
  #define MK_SHIFTUP 1062
  #define MK_CTRLSHIFTUP 1318
  #define MK_CTRLALTUP 806
  #define MK_ALTSHIFTUP 1574
  #define MK_CTRLALTSHIFTUP 1830
  #define MK_RIGHT 39
  #define MK_CTRLRIGHT 295
  #define MK_ALTRIGHT 551
  #define MK_SHIFTRIGHT 1063
  #define MK_CTRLSHIFTRIGHT 1319
  #define MK_CTRLALTRIGHT 807
  #define MK_ALTSHIFTRIGHT 1575
  #define MK_CTRLALTSHIFTRIGHT 1831
  #define MK_DOWN 40
  #define MK_CTRLDOWN 296
  #define MK_ALTDOWN 552
  #define MK_SHIFTDOWN 1064
  #define MK_CTRLSHIFTDOWN 1320
  #define MK_CTRLALTDOWN 808
  #define MK_ALTSHIFTDOWN 1576
  #define MK_CTRLALTSHIFTDOWN 1832
  #define MK_NUM2B 41
  #define MK_CTRLNUM2B 297
  #define MK_ALTNUM2B 553
  #define MK_SHIFTNUM2B 1065
  #define MK_CTRLSHIFTNUM2B 1321
  #define MK_CTRLALTNUM2B 809
  #define MK_ALTSHIFTNUM2B 1577
  #define MK_CTRLALTSHIFTNUM2B 1833
  #define MK_NUM2C 42
  #define MK_CTRLNUM2C 298
  #define MK_ALTNUM2C 554
  #define MK_SHIFTNUM2C 1066
  #define MK_CTRLSHIFTNUM2C 1322
  #define MK_CTRLALTNUM2C 810
  #define MK_ALTSHIFTNUM2C 1578
  #define MK_CTRLALTSHIFTNUM2C 1834
  #define MK_NUM2D 43
  #define MK_CTRLNUM2D 299
  #define MK_ALTNUM2D 555
  #define MK_SHIFTNUM2D 1067
  #define MK_CTRLSHIFTNUM2D 1323
  #define MK_CTRLALTNUM2D 811
  #define MK_ALTSHIFTNUM2D 1579
  #define MK_CTRLALTSHIFTNUM2D 1835
  #define MK_NUM2E 44
  #define MK_CTRLNUM2E 300
  #define MK_ALTNUM2E 556
  #define MK_SHIFTNUM2E 1068
  #define MK_CTRLSHIFTNUM2E 1324
  #define MK_CTRLALTNUM2E 812
  #define MK_ALTSHIFTNUM2E 1580
  #define MK_CTRLALTSHIFTNUM2E 1836
  #define MK_INSERT 45
  #define MK_CTRLINSERT 301
  #define MK_ALTINSERT 557
  #define MK_SHIFTINSERT 1069
  #define MK_CTRLSHIFTINSERT 1325
  #define MK_CTRLALTINSERT 813
  #define MK_ALTSHIFTINSERT 1581
  #define MK_CTRLALTSHIFTINSERT 1837
  #define MK_NUMDEL 46
  #define MK_CTRLNUMDEL 302
  #define MK_ALTNUMDEL 558
  #define MK_SHIFTNUMDEL 1070
  #define MK_CTRLSHIFTNUMDEL 1326
  #define MK_CTRLALTNUMDEL 814
  #define MK_ALTSHIFTNUMDEL 1582
  #define MK_CTRLALTSHIFTNUMDEL 1838
  #define MK_NUMDELB 47
  #define MK_CTRLNUMDELB 303
  #define MK_ALTNUMDELB 559
  #define MK_SHIFTNUMDELB 1071
  #define MK_CTRLSHIFTNUMDELB 1327
  #define MK_CTRLALTNUMDELB 815
  #define MK_ALTSHIFTNUMDELB 1583
  #define MK_CTRLALTSHIFTNUMDELB 1839
  #define MK_0 48
  #define MK_CTRL0 304
  #define MK_ALT0 560
  #define MK_SHIFT0 1072
  #define MK_CTRLSHIFT0 1328
  #define MK_CTRLALT0 816
  #define MK_ALTSHIFT0 1584
  #define MK_CTRLALTSHIFT0 1840
  #define MK_1 49
  #define MK_CTRL1 305
  #define MK_ALT1 561
  #define MK_SHIFT1 1073
  #define MK_CTRLSHIFT1 1329
  #define MK_CTRLALT1 817
  #define MK_ALTSHIFT1 1585
  #define MK_CTRLALTSHIFT1 1841
  #define MK_2 50
  #define MK_CTRL2 306
  #define MK_ALT2 562
  #define MK_SHIFT2 1074
  #define MK_CTRLSHIFT2 1330
  #define MK_CTRLALT2 818
  #define MK_ALTSHIFT2 1586
  #define MK_CTRLALTSHIFT2 1842
  #define MK_3 51
  #define MK_CTRL3 307
  #define MK_ALT3 563
  #define MK_SHIFT3 1075
  #define MK_CTRLSHIFT3 1331
  #define MK_CTRLALT3 819
  #define MK_ALTSHIFT3 1587
  #define MK_CTRLALTSHIFT3 1843
  #define MK_4 52
  #define MK_CTRL4 308
  #define MK_ALT4 564
  #define MK_SHIFT4 1076
  #define MK_CTRLSHIFT4 1332
  #define MK_CTRLALT4 820
  #define MK_ALTSHIFT4 1588
  #define MK_CTRLALTSHIFT4 1844
  #define MK_5 53
  #define MK_CTRL5 309
  #define MK_ALT5 565
  #define MK_SHIFT5 1077
  #define MK_CTRLSHIFT5 1333
  #define MK_CTRLALT5 821
  #define MK_ALTSHIFT5 1589
  #define MK_CTRLALTSHIFT5 1845
  #define MK_6 54
  #define MK_CTRL6 310
  #define MK_ALT6 566
  #define MK_SHIFT6 1078
  #define MK_CTRLSHIFT6 1334
  #define MK_CTRLALT6 822
  #define MK_ALTSHIFT6 1590
  #define MK_CTRLALTSHIFT6 1846
  #define MK_7 55
  #define MK_CTRL7 311
  #define MK_ALT7 567
  #define MK_SHIFT7 1079
  #define MK_CTRLSHIFT7 1335
  #define MK_CTRLALT7 823
  #define MK_ALTSHIFT7 1591
  #define MK_CTRLALTSHIFT7 1847
  #define MK_8 56
  #define MK_CTRL8 312
  #define MK_ALT8 568
  #define MK_SHIFT8 1080
  #define MK_CTRLSHIFT8 1336
  #define MK_CTRLALT8 824
  #define MK_ALTSHIFT8 1592
  #define MK_CTRLALTSHIFT8 1848
  #define MK_9 57
  #define MK_CTRL9 313
  #define MK_ALT9 569
  #define MK_SHIFT9 1081
  #define MK_CTRLSHIFT9 1337
  #define MK_CTRLALT9 825
  #define MK_ALTSHIFT9 1593
  #define MK_CTRLALTSHIFT9 1849
  #define MK_A 65
  #define MK_CTRLA 321
  #define MK_ALTA 577
  #define MK_SHIFTA 1089
  #define MK_CTRLSHIFTA 1345
  #define MK_CTRLALTA 833
  #define MK_ALTSHIFTA 1601
  #define MK_CTRLALTSHIFTA 1857
  #define MK_B 66
  #define MK_CTRLB 322
  #define MK_ALTB 578
  #define MK_SHIFTB 1090
  #define MK_CTRLSHIFTB 1346
  #define MK_CTRLALTB 834
  #define MK_ALTSHIFTB 1602
  #define MK_CTRLALTSHIFTB 1858
  #define MK_C 67
  #define MK_CTRLC 323
  #define MK_ALTC 579
  #define MK_SHIFTC 1091
  #define MK_CTRLSHIFTC 1347
  #define MK_CTRLALTC 835
  #define MK_ALTSHIFTC 1603
  #define MK_CTRLALTSHIFTC 1859
  #define MK_D 68
  #define MK_CTRLD 324
  #define MK_ALTD 580
  #define MK_SHIFTD 1092
  #define MK_CTRLSHIFTD 1348
  #define MK_CTRLALTD 836
  #define MK_ALTSHIFTD 1604
  #define MK_CTRLALTSHIFTD 1860
  #define MK_E 69
  #define MK_CTRLE 325
  #define MK_ALTE 581
  #define MK_SHIFTE 1093
  #define MK_CTRLSHIFTE 1349
  #define MK_CTRLALTE 837
  #define MK_ALTSHIFTE 1605
  #define MK_CTRLALTSHIFTE 1861
  #define MK_F 70
  #define MK_CTRLF 326
  #define MK_ALTF 582
  #define MK_SHIFTF 1094
  #define MK_CTRLSHIFTF 1350
  #define MK_CTRLALTF 838
  #define MK_ALTSHIFTF 1606
  #define MK_CTRLALTSHIFTF 1862
  #define MK_G 71
  #define MK_CTRLG 327
  #define MK_ALTG 583
  #define MK_SHIFTG 1095
  #define MK_CTRLSHIFTG 1351
  #define MK_CTRLALTG 839
  #define MK_ALTSHIFTG 1607
  #define MK_CTRLALTSHIFTG 1863
  #define MK_H 72
  #define MK_CTRLH 328
  #define MK_ALTH 584
  #define MK_SHIFTH 1096
  #define MK_CTRLSHIFTH 1352
  #define MK_CTRLALTH 840
  #define MK_ALTSHIFTH 1608
  #define MK_CTRLALTSHIFTH 1864
  #define MK_I 73
  #define MK_CTRLI 329
  #define MK_ALTI 585
  #define MK_SHIFTI 1097
  #define MK_CTRLSHIFTI 1353
  #define MK_CTRLALTI 841
  #define MK_ALTSHIFTI 1609
  #define MK_CTRLALTSHIFTI 1865
  #define MK_J 74
  #define MK_CTRLJ 330
  #define MK_ALTJ 586
  #define MK_SHIFTJ 1098
  #define MK_CTRLSHIFTJ 1354
  #define MK_CTRLALTJ 842
  #define MK_ALTSHIFTJ 1610
  #define MK_CTRLALTSHIFTJ 1866
  #define MK_K 75
  #define MK_CTRLK 331
  #define MK_ALTK 587
  #define MK_SHIFTK 1099
  #define MK_CTRLSHIFTK 1355
  #define MK_CTRLALTK 843
  #define MK_ALTSHIFTK 1611
  #define MK_CTRLALTSHIFTK 1867
  #define MK_L 76
  #define MK_CTRLL 332
  #define MK_ALTL 588
  #define MK_SHIFTL 1100
  #define MK_CTRLSHIFTL 1356
  #define MK_CTRLALTL 844
  #define MK_ALTSHIFTL 1612
  #define MK_CTRLALTSHIFTL 1868
  #define MK_M 77
  #define MK_CTRLM 333
  #define MK_ALTM 589
  #define MK_SHIFTM 1101
  #define MK_CTRLSHIFTM 1357
  #define MK_CTRLALTM 845
  #define MK_ALTSHIFTM 1613
  #define MK_CTRLALTSHIFTM 1869
  #define MK_N 78
  #define MK_CTRLN 334
  #define MK_ALTN 590
  #define MK_SHIFTN 1102
  #define MK_CTRLSHIFTN 1358
  #define MK_CTRLALTN 846
  #define MK_ALTSHIFTN 1614
  #define MK_CTRLALTSHIFTN 1870
  #define MK_O 79
  #define MK_CTRLO 335
  #define MK_ALTO 591
  #define MK_SHIFTO 1103
  #define MK_CTRLSHIFTO 1359
  #define MK_CTRLALTO 847
  #define MK_ALTSHIFTO 1615
  #define MK_CTRLALTSHIFTO 1871
  #define MK_P 80
  #define MK_CTRLP 336
  #define MK_ALTP 592
  #define MK_SHIFTP 1104
  #define MK_CTRLSHIFTP 1360
  #define MK_CTRLALTP 848
  #define MK_ALTSHIFTP 1616
  #define MK_CTRLALTSHIFTP 1872
  #define MK_Q 81
  #define MK_CTRLQ 337
  #define MK_ALTQ 593
  #define MK_SHIFTQ 1105
  #define MK_CTRLSHIFTQ 1361
  #define MK_CTRLALTQ 849
  #define MK_ALTSHIFTQ 1617
  #define MK_CTRLALTSHIFTQ 1873
  #define MK_R 82
  #define MK_CTRLR 338
  #define MK_ALTR 594
  #define MK_SHIFTR 1106
  #define MK_CTRLSHIFTR 1362
  #define MK_CTRLALTR 850
  #define MK_ALTSHIFTR 1618
  #define MK_CTRLALTSHIFTR 1874
  #define MK_S 83
  #define MK_CTRLS 339
  #define MK_ALTS 595
  #define MK_SHIFTS 1107
  #define MK_CTRLSHIFTS 1363
  #define MK_CTRLALTS 851
  #define MK_ALTSHIFTS 1619
  #define MK_CTRLALTSHIFTS 1875
  #define MK_T 84
  #define MK_CTRLT 340
  #define MK_ALTT 596
  #define MK_SHIFTT 1108
  #define MK_CTRLSHIFTT 1364
  #define MK_CTRLALTT 852
  #define MK_ALTSHIFTT 1620
  #define MK_CTRLALTSHIFTT 1876
  #define MK_U 85
  #define MK_CTRLU 341
  #define MK_ALTU 597
  #define MK_SHIFTU 1109
  #define MK_CTRLSHIFTU 1365
  #define MK_CTRLALTU 853
  #define MK_ALTSHIFTU 1621
  #define MK_CTRLALTSHIFTU 1877
  #define MK_V 86
  #define MK_CTRLV 342
  #define MK_ALTV 598
  #define MK_SHIFTV 1110
  #define MK_CTRLSHIFTV 1366
  #define MK_CTRLALTV 854
  #define MK_ALTSHIFTV 1622
  #define MK_CTRLALTSHIFTV 1878
  #define MK_W 87
  #define MK_CTRLW 343
  #define MK_ALTW 599
  #define MK_SHIFTW 1111
  #define MK_CTRLSHIFTW 1367
  #define MK_CTRLALTW 855
  #define MK_ALTSHIFTW 1623
  #define MK_CTRLALTSHIFTW 1879
  #define MK_X 88
  #define MK_CTRLX 344
  #define MK_ALTX 600
  #define MK_SHIFTX 1112
  #define MK_CTRLSHIFTX 1368
  #define MK_CTRLALTX 856
  #define MK_ALTSHIFTX 1624
  #define MK_CTRLALTSHIFTX 1880
  #define MK_Y 89
  #define MK_CTRLY 345
  #define MK_ALTY 601
  #define MK_SHIFTY 1113
  #define MK_CTRLSHIFTY 1369
  #define MK_CTRLALTY 857
  #define MK_ALTSHIFTY 1625
  #define MK_CTRLALTSHIFTY 1881
  #define MK_Z 90
  #define MK_CTRLZ 346
  #define MK_ALTZ 602
  #define MK_SHIFTZ 1114
  #define MK_CTRLSHIFTZ 1370
  #define MK_CTRLALTZ 858
  #define MK_ALTSHIFTZ 1626
  #define MK_CTRLALTSHIFTZ 1882
  #define MK_NUM0 96
  #define MK_CTRLNUM0 352
  #define MK_ALTNUM0 608
  #define MK_SHIFTNUM0 1120
  #define MK_CTRLSHIFTNUM0 1376
  #define MK_CTRLALTNUM0 864
  #define MK_ALTSHIFTNUM0 1632
  #define MK_CTRLALTSHIFTNUM0 1888
  #define MK_NUM1 97
  #define MK_CTRLNUM1 353
  #define MK_ALTNUM1 609
  #define MK_SHIFTNUM1 1121
  #define MK_CTRLSHIFTNUM1 1377
  #define MK_CTRLALTNUM1 865
  #define MK_ALTSHIFTNUM1 1633
  #define MK_CTRLALTSHIFTNUM1 1889
  #define MK_NUM2 98
  #define MK_CTRLNUM2 354
  #define MK_ALTNUM2 610
  #define MK_SHIFTNUM2 1122
  #define MK_CTRLSHIFTNUM2 1378
  #define MK_CTRLALTNUM2 866
  #define MK_ALTSHIFTNUM2 1634
  #define MK_CTRLALTSHIFTNUM2 1890
  #define MK_NUM3 99
  #define MK_CTRLNUM3 355
  #define MK_ALTNUM3 611
  #define MK_SHIFTNUM3 1123
  #define MK_CTRLSHIFTNUM3 1379
  #define MK_CTRLALTNUM3 867
  #define MK_ALTSHIFTNUM3 1635
  #define MK_CTRLALTSHIFTNUM3 1891
  #define MK_NUM4 100
  #define MK_CTRLNUM4 356
  #define MK_ALTNUM4 612
  #define MK_SHIFTNUM4 1124
  #define MK_CTRLSHIFTNUM4 1380
  #define MK_CTRLALTNUM4 868
  #define MK_ALTSHIFTNUM4 1636
  #define MK_CTRLALTSHIFTNUM4 1892
  #define MK_NUM5 101
  #define MK_CTRLNUM5 357
  #define MK_ALTNUM5 613
  #define MK_SHIFTNUM5 1125
  #define MK_CTRLSHIFTNUM5 1381
  #define MK_CTRLALTNUM5 869
  #define MK_ALTSHIFTNUM5 1637
  #define MK_CTRLALTSHIFTNUM5 1893
  #define MK_NUM6 102
  #define MK_CTRLNUM6 358
  #define MK_ALTNUM6 614
  #define MK_SHIFTNUM6 1126
  #define MK_CTRLSHIFTNUM6 1382
  #define MK_CTRLALTNUM6 870
  #define MK_ALTSHIFTNUM6 1638
  #define MK_CTRLALTSHIFTNUM6 1894
  #define MK_NUM7 103
  #define MK_CTRLNUM7 359
  #define MK_ALTNUM7 615
  #define MK_SHIFTNUM7 1127
  #define MK_CTRLSHIFTNUM7 1383
  #define MK_CTRLALTNUM7 871
  #define MK_ALTSHIFTNUM7 1639
  #define MK_CTRLALTSHIFTNUM7 1895
  #define MK_NUM8 104
  #define MK_CTRLNUM8 360
  #define MK_ALTNUM8 616
  #define MK_SHIFTNUM8 1128
  #define MK_CTRLSHIFTNUM8 1384
  #define MK_CTRLALTNUM8 872
  #define MK_ALTSHIFTNUM8 1640
  #define MK_CTRLALTSHIFTNUM8 1896
  #define MK_NUM9 105
  #define MK_CTRLNUM9 361
  #define MK_ALTNUM9 617
  #define MK_SHIFTNUM9 1129
  #define MK_CTRLSHIFTNUM9 1385
  #define MK_CTRLALTNUM9 873
  #define MK_ALTSHIFTNUM9 1641
  #define MK_CTRLALTSHIFTNUM9 1897
  #define MK_NUMASTERISK 106
  #define MK_CTRLNUMASTERISK 362
  #define MK_ALTNUMASTERISK 618
  #define MK_SHIFTNUMASTERISK 1130
  #define MK_CTRLSHIFTNUMASTERISK 1386
  #define MK_CTRLALTNUMASTERISK 874
  #define MK_ALTSHIFTNUMASTERISK 1642
  #define MK_CTRLALTSHIFTNUMASTERISK 1898
  #define MK_NUMPLUS 107
  #define MK_CTRLNUMPLUS 363
  #define MK_ALTNUMPLUS 619
  #define MK_SHIFTNUMPLUS 1131
  #define MK_CTRLSHIFTNUMPLUS 1387
  #define MK_CTRLALTNUMPLUS 875
  #define MK_ALTSHIFTNUMPLUS 1643
  #define MK_CTRLALTSHIFTNUMPLUS 1899
  #define MK_NUMPLUSA 108
  #define MK_CTRLNUMPLUSA 364
  #define MK_ALTNUMPLUSA 620
  #define MK_SHIFTNUMPLUSA 1132
  #define MK_CTRLSHIFTNUMPLUSA 1388
  #define MK_CTRLALTNUMPLUSA 876
  #define MK_ALTSHIFTNUMPLUSA 1644
  #define MK_CTRLALTSHIFTNUMPLUSA 1900
  #define MK_NUMMINUS 109
  #define MK_CTRLNUMMINUS 365
  #define MK_ALTNUMMINUS 621
  #define MK_SHIFTNUMMINUS 1133
  #define MK_CTRLSHIFTNUMMINUS 1389
  #define MK_CTRLALTNUMMINUS 877
  #define MK_ALTSHIFTNUMMINUS 1645
  #define MK_CTRLALTSHIFTNUMMINUS 1901
  #define MK_NUMPERIOD 110
  #define MK_CTRLNUMPERIOD 366
  #define MK_ALTNUMPERIOD 622
  #define MK_SHIFTNUMPERIOD 1134
  #define MK_CTRLSHIFTNUMPERIOD 1390
  #define MK_CTRLALTNUMPERIOD 878
  #define MK_ALTSHIFTNUMPERIOD 1646
  #define MK_CTRLALTSHIFTNUMPERIOD 1902
  #define MK_NUMSLASH 111
  #define MK_CTRLNUMSLASH 367
  #define MK_ALTNUMSLASH 623
  #define MK_SHIFTNUMSLASH 1135
  #define MK_CTRLSHIFTNUMSLASH 1391
  #define MK_CTRLALTNUMSLASH 879
  #define MK_ALTSHIFTNUMSLASH 1647
  #define MK_CTRLALTSHIFTNUMSLASH 1903
  #define MK_F1 112
  #define MK_CTRLF1 368
  #define MK_ALTF1 624
  #define MK_SHIFTF1 1136
  #define MK_CTRLSHIFTF1 1392
  #define MK_CTRLALTF1 880
  #define MK_ALTSHIFTF1 1648
  #define MK_CTRLALTSHIFTF1 1904
  #define MK_F2 113
  #define MK_CTRLF2 369
  #define MK_ALTF2 625
  #define MK_SHIFTF2 1137
  #define MK_CTRLSHIFTF2 1393
  #define MK_CTRLALTF2 881
  #define MK_ALTSHIFTF2 1649
  #define MK_CTRLALTSHIFTF2 1905
  #define MK_F3 114
  #define MK_CTRLF3 370
  #define MK_ALTF3 626
  #define MK_SHIFTF3 1138
  #define MK_CTRLSHIFTF3 1394
  #define MK_CTRLALTF3 882
  #define MK_ALTSHIFTF3 1650
  #define MK_CTRLALTSHIFTF3 1906
  #define MK_F4 115
  #define MK_CTRLF4 371
  #define MK_ALTF4 627
  #define MK_SHIFTF4 1139
  #define MK_CTRLSHIFTF4 1395
  #define MK_CTRLALTF4 883
  #define MK_ALTSHIFTF4 1651
  #define MK_CTRLALTSHIFTF4 1907
  #define MK_F5 116
  #define MK_CTRLF5 372
  #define MK_ALTF5 628
  #define MK_SHIFTF5 1140
  #define MK_CTRLSHIFTF5 1396
  #define MK_CTRLALTF5 884
  #define MK_ALTSHIFTF5 1652
  #define MK_CTRLALTSHIFTF5 1908
  #define MK_F6 117
  #define MK_CTRLF6 373
  #define MK_ALTF6 629
  #define MK_SHIFTF6 1141
  #define MK_CTRLSHIFTF6 1397
  #define MK_CTRLALTF6 885
  #define MK_ALTSHIFTF6 1653
  #define MK_CTRLALTSHIFTF6 1909
  #define MK_F7 118
  #define MK_CTRLF7 374
  #define MK_ALTF7 630
  #define MK_SHIFTF7 1142
  #define MK_CTRLSHIFTF7 1398
  #define MK_CTRLALTF7 886
  #define MK_ALTSHIFTF7 1654
  #define MK_CTRLALTSHIFTF7 1910
  #define MK_F8 119
  #define MK_CTRLF8 375
  #define MK_ALTF8 631
  #define MK_SHIFTF8 1143
  #define MK_CTRLSHIFTF8 1399
  #define MK_CTRLALTF8 887
  #define MK_ALTSHIFTF8 1655
  #define MK_CTRLALTSHIFTF8 1911
  #define MK_F9 120
  #define MK_CTRLF9 376
  #define MK_ALTF9 632
  #define MK_SHIFTF9 1144
  #define MK_CTRLSHIFTF9 1400
  #define MK_CTRLALTF9 888
  #define MK_ALTSHIFTF9 1656
  #define MK_CTRLALTSHIFTF9 1912
  #define MK_F10 121
  #define MK_CTRLF10 377
  #define MK_ALTF10 633
  #define MK_SHIFTF10 1145
  #define MK_CTRLSHIFTF10 1401
  #define MK_CTRLALTF10 889
  #define MK_ALTSHIFTF10 1657
  #define MK_CTRLALTSHIFTF10 1913
  #define MK_F11 122
  #define MK_CTRLF11 378
  #define MK_ALTF11 634
  #define MK_SHIFTF11 1146
  #define MK_CTRLSHIFTF11 1402
  #define MK_CTRLALTF11 890
  #define MK_ALTSHIFTF11 1658
  #define MK_CTRLALTSHIFTF11 1914
  #define MK_F12 123
  #define MK_CTRLF12 379
  #define MK_ALTF12 635
  #define MK_SHIFTF12 1147
  #define MK_CTRLSHIFTF12 1403
  #define MK_CTRLALTF12 891
  #define MK_ALTSHIFTF12 1659
  #define MK_CTRLALTSHIFTF12 1915
  #define MK_SEMICOLON 186
  #define MK_CTRLSEMICOLON 442
  #define MK_ALTSEMICOLON 698
  #define MK_SHIFTSEMICOLON 1210
  #define MK_CTRLSHIFTSEMICOLON 1466
  #define MK_CTRLALTSEMICOLON 954
  #define MK_ALTSHIFTSEMICOLON 1722
  #define MK_CTRLALTSHIFTSEMICOLON 1978
  #define MK_EQUAL 187
  #define MK_CTRLEQUAL 443
  #define MK_ALTEQUAL 699
  #define MK_SHIFTEQUAL 1211
  #define MK_CTRLSHIFTEQUAL 1467
  #define MK_CTRLALTEQUAL 955
  #define MK_ALTSHIFTEQUAL 1723
  #define MK_CTRLALTSHIFTEQUAL 1979
  #define MK_COMMA 188
  #define MK_CTRLCOMMA 444
  #define MK_ALTCOMMA 700
  #define MK_SHIFTCOMMA 1212
  #define MK_CTRLSHIFTCOMMA 1468
  #define MK_CTRLALTCOMMA 956
  #define MK_ALTSHIFTCOMMA 1724
  #define MK_CTRLALTSHIFTCOMMA 1980
  #define MK_MINUS 189
  #define MK_CTRLMINUS 445
  #define MK_ALTMINUS 701
  #define MK_SHIFTMINUS 1213
  #define MK_CTRLSHIFTMINUS 1469
  #define MK_CTRLALTMINUS 957
  #define MK_ALTSHIFTMINUS 1725
  #define MK_CTRLALTSHIFTMINUS 1981
  #define MK_PERIOD 190
  #define MK_CTRLPERIOD 446
  #define MK_ALTPERIOD 702
  #define MK_SHIFTPERIOD 1214
  #define MK_CTRLSHIFTPERIOD 1470
  #define MK_CTRLALTPERIOD 958
  #define MK_ALTSHIFTPERIOD 1726
  #define MK_CTRLALTSHIFTPERIOD 1982
  #define MK_SLASH 191
  #define MK_CTRLSLASH 447
  #define MK_ALTSLASH 703
  #define MK_SHIFTSLASH 1215
  #define MK_CTRLSHIFTSLASH 1471
  #define MK_CTRLALTSLASH 959
  #define MK_ALTSHIFTSLASH 1727
  #define MK_CTRLALTSHIFTSLASH 1983
  #define MK_BACKQUOTE 192
  #define MK_CTRLBACKQUOTE 448
  #define MK_ALTBACKQUOTE 704
  #define MK_SHIFTBACKQUOTE 1216
  #define MK_CTRLSHIFTBACKQUOTE 1472
  #define MK_CTRLALTBACKQUOTE 960
  #define MK_ALTSHIFTBACKQUOTE 1728
  #define MK_CTRLALTSHIFTBACKQUOTE 1984
  #define MK_LEFTBRACKET 219
  #define MK_CTRLLEFTBRACKET 475
  #define MK_ALTLEFTBRACKET 731
  #define MK_SHIFTLEFTBRACKET 1243
  #define MK_CTRLSHIFTLEFTBRACKET 1499
  #define MK_CTRLALTLEFTBRACKET 987
  #define MK_ALTSHIFTLEFTBRACKET 1755
  #define MK_CTRLALTSHIFTLEFTBRACKET 2011
  #define MK_BACKSLASH 220
  #define MK_CTRLBACKSLASH 476
  #define MK_ALTBACKSLASH 732
  #define MK_SHIFTBACKSLASH 1244
  #define MK_CTRLSHIFTBACKSLASH 1500
  #define MK_CTRLALTBACKSLASH 988
  #define MK_ALTSHIFTBACKSLASH 1756
  #define MK_CTRLALTSHIFTBACKSLASH 2012
  #define MK_RIGHTBRACKET 221
  #define MK_CTRLRIGHTBRACKET 477
  #define MK_ALTRIGHTBRACKET 733
  #define MK_SHIFTRIGHTBRACKET 1245
  #define MK_CTRLSHIFTRIGHTBRACKET 1501
  #define MK_CTRLALTRIGHTBRACKET 989
  #define MK_ALTSHIFTRIGHTBRACKET 1757
  #define MK_CTRLALTSHIFTRIGHTBRACKET 2013
  #define MK_QUOTE 222
  #define MK_CTRLQUOTE 478
  #define MK_ALTQUOTE 734
  #define MK_SHIFTQUOTE 1246
  #define MK_CTRLSHIFTQUOTE 1502
  #define MK_CTRLALTQUOTE 990
  #define MK_ALTSHIFTQUOTE 1758
  #define MK_CTRLALTSHIFTQUOTE 2014

